Deletes all locally cached carbon market data files. The next call to any data function will re-download.
See also
Other configuration:
co2_cache_info()
Deletes all locally cached carbon market data files. The next call to any data function will re-download.
Other configuration:
co2_cache_info()