Skip to contents

Returns information about the local cache: directory, file count, size, and list of cached files. Useful for debugging stale results or deciding whether to call co2_clear_cache().

Usage

co2_cache_info()

Value

A list with elements dir, n_files, size_bytes, size_human, and files (a data frame with name, size_bytes, modified).

See also

Other configuration: co2_clear_cache()

Examples

# \donttest{
op <- options(carbondata.cache_dir = tempdir())
co2_cache_info()
#> $dir
#> [1] "/tmp/RtmpbMegKM"
#> 
#> $n_files
#> [1] 2
#> 
#> $size_bytes
#> [1] 8192
#> 
#> $size_human
#> [1] "8.0 KB"
#> 
#> $files
#>                                     name size_bytes            modified
#> 1 bslib-8a92d22979ec96a3105b4f8cbcdeeec5       4096 2026-05-04 19:16:44
#> 2                                downlit       4096 2026-05-04 19:16:46
#> 
options(op)
# }