Fetches the California Cap-and-Trade program overall cap and allocation channels, by vintage year.
See also
Other compliance markets:
co2_california_prices(),
co2_rggi_allowances(),
co2_rggi_state_proceeds(),
co2_ukets(),
co2_ukets_allocations()
Examples
# \donttest{
op <- options(carbondata.cache_dir = tempdir())
try({
caps <- co2_california_caps()
})
#> ℹ Downloading California overall caps...
#> Error in co2_download(url, dest, refresh = refresh) : Download of
#> <https://ww2.arb.ca.gov/sites/default/files/2025-06/nc-OverallCaps.csv>
#> returned HTTP 202 with an empty body.
#> ℹ The publisher may be refusing automated clients from this network.
#> Retry later, or report at
#> https://github.com/charlescoverdale/carbondata/issues.
options(op)
# }