Fetches the California Air Resources Board auction settlement price time series, updated quarterly after each joint California- Quebec auction.
See also
Other compliance markets:
co2_california_caps(),
co2_rggi_allowances(),
co2_rggi_state_proceeds(),
co2_ukets(),
co2_ukets_allocations()
Examples
# \donttest{
op <- options(carbondata.cache_dir = tempdir())
try({
prices <- co2_california_prices()
})
#> ℹ Downloading California Cap-and-Trade auction prices...
#> Error in co2_download(url, dest, refresh = refresh) : Download of
#> <https://ww2.arb.ca.gov/sites/default/files/2022-12/nc-allowance_prices.csv>
#> returned HTTP 202 with an empty body.
#> ℹ The publisher may be refusing automated clients from this network.
#> Retry later, or report at
#> https://github.com/charlescoverdale/carbondata/issues.
options(op)
# }