Skip to contents

Fetches the California Air Resources Board auction settlement price time series, updated quarterly after each joint California- Quebec auction.

Usage

co2_california_prices(refresh = FALSE)

Arguments

refresh

Re-download? Default FALSE.

Value

A data frame with joint_auction, quarter, settlement_price_usd, reserve_price_usd.

Examples

# \donttest{
op <- options(carbondata.cache_dir = tempdir())
prices <- co2_california_prices()
#>  Downloading California Cap-and-Trade auction prices...
options(op)
# }