Returns free allowance allocations per installation per year.
Same source file as co2_euets_emissions().
Arguments
- country
Optional character vector of two-letter registry codes to filter (e.g.
c("DE", "FR", "PL")).- year
Optional integer vector of emissions years. When
NULL, returns all years in the latest published file. Note that the file year (e.g. "2025") refers to publication year; emissions data covers calendar years up to publication year -1.- file_year
Publication year of the DG CLIMA file to use. Default is the latest year available in the package (see
co2_euets_files()).- refresh
Logical. Re-download? Default
FALSE.